@@ -1,12 +1,5 @@
 package constants
 
-// Application constants
-
-const (
-	AppName = "steampipe"
-	FdwName = "steampipe-postgres-fdw"
-)
-
 const (
 	ClientConnectionAppNamePrefix       = "steampipe_client"
 	ServiceConnectionAppNamePrefix      = "steampipe_service"
