@@ -1,7 +1,7 @@
 package db_common
 
 import (
-	"github.com/turbot/pipe-fittings/error_helpers"
+	"github.com/turbot/pipe-fittings/v2/error_helpers"
 )
 
 type AcquireSessionResult struct {
