@@ -2,7 +2,7 @@ package db_common
 
 import (
 	"github.com/jackc/pgx/v5/pgconn"
-	"github.com/turbot/steampipe/pkg/db/sslio"
+	"github.com/turbot/steampipe/v2/pkg/db/sslio"
 )
 
 func AddRootCertToConfig(config *pgconn.Config, certLocation string) error {
