@@ -4,9 +4,9 @@ import (
 	"context"
 	"log"
 
-	"github.com/turbot/pipe-fittings/error_helpers"
-	"github.com/turbot/steampipe/pkg/db/db_local"
-	"github.com/turbot/steampipe/pkg/steampipeconfig"
+	"github.com/turbot/pipe-fittings/v2/error_helpers"
+	"github.com/turbot/steampipe/v2/pkg/db/db_local"
+	"github.com/turbot/steampipe/v2/pkg/steampipeconfig"
 )
 
 func (m *PluginManager) SendPostgresSchemaNotification(ctx context.Context) error {
